tox and nose — tox 2.9.0rc2.dev63 documentation

# tox and nose

It is easy to integrate nosetests runs with tox. For starters here is a simple `tox.ini` config to configure your project for running with nose:

## Basic nosetests example

Assuming the following layout:

    tox.ini      # see below for content
    setup.py     # a classic distutils/setuptools setup.py file

and the following `tox.ini` content:

    [testenv]
    deps=nose
    commands= nosetests [] # substitute with tox' positional arguments

you can invoke `tox` in the directory where your `tox.ini` resides. `tox` will sdist-package your project create two virtualenv environments with the `python2.6` and `python2.5` interpreters, respectively, and will then run the specified test command.

## More examples?

You can use and combine other features of `tox` with your tox runs, e.g. Integrate “sphinx” doc checks. If you figure out some particular configurations for nose/tox interactions please submit them.

Also you might want to checkout General tips and tricks.